Description Usage Arguments Examples
View source: R/generateBlissMatrix.R
This function, given an input dataframe containing info on library dose, anchor dose, and inhibition, generates a list of bliss matrices for each combination. The matrix is intended to be later used as input to a heatmap function.
1 | generateBlissMatrix(drug.data)
|
drug.data |
The input anchor / drug data. |
1 | generateBlissMatrix(drug.data = my_data)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.