Description Usage Arguments Examples
This function reads in a .xlsx file, and outputs the name of the file being read before returning it. Useful for keeping track of data in large for loops.
1 |
parent.dir |
The directory within which the .xlsx file is located. |
file.name |
The .xlsx file you wish to load. |
sheet.name |
Which sheet to load. |
col.names |
Should column names be loaded? Defaults to TRUE. |
1 | readData(parent.dir = "path/to/data/dir/", sheet.name = 1, file.name = "file.xlsx")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.