This file assigns our metadata and raw plate data objects to the global environment upon loading the package.
1 | .onLoad(libname, pkgname)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.